package metrics

import (
	"github.com/prometheus/client_golang/prometheus"
	"github.com/prometheus/client_golang/prometheus/promauto"
)

const (
	MetricStateIdle float64 = iota
	MetricStateCooling
	MetricStateHeating
)

var (
	State = promauto.NewGauge(prometheus.GaugeOpts{
		Namespace: "fermentord",
		Subsystem: "state",
		Name:      "current",
		Help:      "The state of the fermentor. 0=idle, 1=cooling, 2=heating",
	})

	TemperatureSensorReadingDegreesCelcius = promauto.NewGaugeVec(
		prometheus.GaugeOpts{
			Namespace: "fermentord",
			Subsystem: "temperature",
			Name:      "sensor_reading_degrees_celcius",
			Help:      "Temperature in degrees celcius.",
		},
		[]string{
			"sensor",
		},
	)

	TemperatureSensorReadingDurationSeconds = promauto.NewHistogramVec(
		prometheus.HistogramOpts{
			Namespace: "fermentord",
			Subsystem: "temperature",
			Name:      "sensor_reading_duration_seconds",
			Help:      "Duration of temperature sensor readings.",
			Buckets:   []float64{0.25, 0.5, 0.75, 1, 1.25, 1.5},
		},
		[]string{
			"sensor",
		},
	)

	PID = promauto.NewGaugeVec(
		prometheus.GaugeOpts{
			Namespace: "fermentord",
			Subsystem: "pid",
			Name:      "variable_value",
			Help:      "PID variable",
		},
		[]string{
			"var",
			"pid",
		},
	)
)
